@@ -3,7 +3,7 @@
 #
 # SoundConverter - GNOME application for converting between audio formats. 
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2006 Gautier Portet
+# Copyright 2005-2007 Gautier Portet
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,9 +23,6 @@ NAME = "SoundConverter"
 VERSION = "@version@"
 GLADE = "@datadir@/soundconverter/soundconverter.glade"
 
-if "datadir" in GLADE:
-	GLADE = "./data"
-
 print "%s %s" % (NAME, VERSION)
 
 # Python standard stuff.
@@ -41,22 +38,20 @@ import urllib
 import time
 
 # GNOME and related stuff.
-import pygtk
-pygtk.require("2.0")
-import gtk
-import gtk.glade
-import gnome
-import gnome.ui
-import gconf
-import gobject
-gobject.threads_init()
-
 try:
-	# gnome.vfs is deprecated
+	import pygtk
+	pygtk.require("2.0")
+	import gtk
+	import gtk.glade
+	import gnome
+	import gnome.ui
+	import gconf
+	import gobject
+	gobject.threads_init()
 	import gnomevfs
 except ImportError:
-	import gnome.vfs
-	gnomevfs = gnome.vfs
+	print "%s needs gnome-python 2.10!" % NAME
+	sys.exit(1)
 
 # GStreamer
 try:
@@ -65,12 +60,7 @@ try:
 	pygst.require('0.10')
 	import gst
 except ImportError:
-	# 0.8
-	import gst
-	pygst = None
-
-if gst.gst_version < (0,10,0):
-	print "%s needs GStreamer 0.10, you have version: %s" % (NAME, ".".join([str(s) for s in gst.gst_version]))
+	print "%s needs python-gstreamer 0.10!" % NAME
 	sys.exit(1)
 
 print "  using Gstreamer version: %s, Python binding version: %s" % (
@@ -83,7 +73,7 @@ FORMAT_PERCENT_SCALE = 10000
 #localization
 import locale
 import gettext
-PACKAGE = "soundconverter"
+PACKAGE = NAME.lower()
 gettext.bindtextdomain(PACKAGE,"@datadir@/locale")
 locale.setlocale(locale.LC_ALL,"")
 gettext.textdomain(PACKAGE)
@@ -93,7 +83,7 @@ gtk.glade.bindtextdomain(PACKAGE,"@datadir@/locale")
 gtk.glade.textdomain(PACKAGE)
 
 TRANSLATORS = ("""
-Guillaume Bedot <guillaume.bedot wanadoo.fr> (French)
+Guillaume Bedot <littletux zarb.org> (French)
 Dominik Zabłotny <dominz wp.pl> (Polish) 
 Jonh Wendell <wendell bani.com.br> (Portuguese Brazilian)
 Marc E. <m4rccd yahoo.com> (Spanish)
@@ -237,6 +227,12 @@ def filename_escape(str):
 	str = str.replace("!","\!")
 	return str
 
+required_elements = ("decodebin", "fakesink", "audioconvert", "typefind")
+for element in required_elements:
+	if not gst.element_factory_find(element):
+		print "required gstreamer element '%s' not found." % element
+		sys.exit(1)
+
 if gst.element_factory_find("gnomevfssrc"):
 	gstreamer_source = "gnomevfssrc"
 	gstreamer_sink = "gnomevfssink"
@@ -249,21 +245,26 @@ else:
 	encode_filename = file_encode_filename
 	print "  NOT using gnomevfssrc, look for a gnomevfs gstreamer package."
 
-have_id3v2mux = True
-if not gst.element_factory_find("id3v2mux"):
-	have_id3v2mux = False
-	print "  id3v2mux element not found?"
 
-have_xingmux = True
-if not gst.element_factory_find("xingmux"):
-	have_xingmux = False
-	print "  xingmux element not found."
+encoders = ( 
+	("flacenc",   "FLAC"), 
+	("wavenc",    "WAV"),
+	("vorbisenc", "Ogg Vorbis"),
+	("oggmux",    "Ogg Vorbis"),
+	("id3v2mux",  "MP3 Tags"),
+	("xingmux",   ""),
+	("lame",      "MP3"))
 
-have_lame = True
-if not gst.element_factory_find("lame"):
-	have_lame = False
-	print "  GStreamer MP3 Encoder not found, MP3 output disabled."
+for encoder, name in encoders:
+	have_it = True
+	if not gst.element_factory_find(encoder):
+		have_it = False
+		if name:
+			print "  '%s' element not found, disabling %s." % (encoder, name)
+	exec("have_%s = %s" % (encoder, have_it))
 
+if not have_oggmux:
+	have_vorbis = False
 
 # logging & debugging  
 
@@ -448,7 +449,7 @@ class TargetNameGenerator:
 			folder = root
 		else:
 			folder = self.folder
-		result = urllib.quote(os.path.join(folder, result))
+		result = os.path.join(folder, urllib.quote(result))
 
 		tuple = (u.scheme, host, result, "", u.fragment_identifier)
 		u2 = urlparse.urlunsplit(tuple)
@@ -1397,22 +1398,28 @@ class PreferencesDialog:
 
 		mime_type = self.get_string("output-mime-type")
 
-		# desactivate mp3 output if encoder plugin is not present
+		widgets = {		"audio/x-vorbis": (have_vorbisenc, "output_mime_type_ogg_vorbis"),
+						"audio/x-flac"  : (have_flacenc, "output_mime_type_flac"),
+						"audio/x-wav"   : (have_wavenc, "output_mime_type_wav"),
+						"audio/mpeg"    : (have_lame, "output_mime_type_mp3"),
+					}
+
+		# desactivate output if encoder plugin is not present
+		for mime, d in widgets.iteritems():
+			encoder, widget = d
+			if not encoder:
+				w = glade.get_widget(widget)
+				w.set_sensitive(False)
+				if mime_type == mime:
+					mime_type = self.defaults["output-mime-type"]
+
+		# display information about mp3 encoding
 		if not have_lame:
-			w = glade.get_widget("output_mime_type_mp3")
-			w.set_sensitive(False)
-			if mime_type == "audio/mpeg":
-				mime_type = self.defaults["output-mime-type"]
 			w = glade.get_widget("lame_absent")
 			w.show()
-			
 		
-		widget_name = {
-						"audio/x-vorbis": "output_mime_type_ogg_vorbis",
-						"audio/x-flac": "output_mime_type_flac",
-						"audio/x-wav": "output_mime_type_wav",
-						"audio/mpeg": "output_mime_type_mp3",
-					}.get(mime_type, None)
+		widget_name = widgets.get(mime_type, None)[1]
+		print widget_name
 		if widget_name:
 			w = glade.get_widget(widget_name)
 			w.set_active(True)
